OC.L10N.register(
    "lib",
    {
    "Unknown filetype" : "Onbekende lêertipe",
    "Invalid image" : "Ongeldige beeld",
    "Files" : " Lêers",
    "seconds ago" : "sekondes gelede",
    "File already exists" : "Lêer bestaan reeds",
    "__language_name__" : "Afrikaans",
    "Help" : "Hulp",
    "Apps" : "Toeps",
    "Settings" : "Instellings",
    "Log out" : "Meld af",
    "Users" : "Gebruikers",
    "Email" : "E-pos",
    "Phone" : "Foon",
    "Twitter" : "Twitter",
    "Website" : "Webwerf",
    "Address" : "Adres",
    "Profile picture" : "Profielprent",
    "About" : "Oor",
    "Open »%s«" : "Open »%s«",
    "Sunday" : "Sondag",
    "Monday" : "Maandag",
    "Tuesday" : "Dinsdag",
    "Wednesday" : "Woensdag",
    "Thursday" : "Donderdag",
    "Friday" : "Vrydag",
    "Saturday" : "Saterdag",
    "a safe home for all your data" : "’n veilige tuiste vir al u data",
    "Storage is temporarily not available" : "Berging is tydelik nie beskikbaar nie",
    "Full name" : "Volle naam",
    "Unknown user" : "Onbekende gebruiker"
},
"nplurals=2; plural=(n != 1);");
